@@ -67,7 +67,7 @@ class Kfzcheck(object):
         Config.add_section('Country')
         Config.set('Country', 'firstload', 'de') # first standard load is the german file
         Config.write(ini_file)
-        ini_file.close
+        ini_file.close()
         
     Config.read(kfzcheck_ini)
     firstload = Config.get('Country', 'firstload') # load the country that specified in the configuration file
@@ -123,6 +123,7 @@ class Kfzcheck(object):
     def search(self, widget=None, entry=None, country=None):
         self.deletecolumn() # delete the whole column before you add new items
         self.count_rows = 0 # for top, middle, bottom scrolling    
+        self.top.set_active(True) # set the Top filter button active (because we are at the top)
         try:
             searchword = unicode(entry.get_text(), 'utf-8')
         except AttributeError:
